package mt.edu.um.nlgapp;

import mt.edu.um.nlgapp.docplan.DocPlan;
import mt.edu.um.nlgapp.docplan.DocPlanner;
import mt.edu.um.nlgapp.microplan.Microplanner;
import mt.edu.um.nlgapp.microplan.NLGRealiser;
import uk.ac.abdn.carados.OntologyHandler;

/**
 * This is the class for an NLG application. It requires an document planner, a
 * microplanner and a realiser.
 * 
 * @author bertugatt
 * 
 */
public abstract class NLGApplication {

	private DocPlanner docplanner;
	private Microplanner microplanner;
	private NLGRealiser realiser;

	/**
	 * Default (empty) constructor
	 */
	public NLGApplication() {

	}

	/**
	 * Constructor with parameters
	 * 
	 * @param dp
	 *            the doc planner
	 * @param mp
	 *            the microplanner
	 * @param r
	 *            the realiser
	 */
	public NLGApplication(DocPlanner dp, Microplanner mp, NLGRealiser r) {
		setDocplanner(dp);
		setMicroplanner(mp);
		setRealiser(r);
	}

	/**
	 * @return the docplanner
	 */
	public DocPlanner getDocplanner() {
		return docplanner;
	}

	/**
	 * @param docplanner
	 *            the docplanner to set
	 */
	public void setDocplanner(DocPlanner docplanner) {
		this.docplanner = docplanner;
	}

	/**
	 * @return the microplanner
	 */
	public Microplanner getMicroplanner() {
		return microplanner;
	}

	/**
	 * @param microplanner
	 *            the microplanner to set
	 */
	public void setMicroplanner(Microplanner microplanner) {
		this.microplanner = microplanner;
	}

	/**
	 * @return the realiser
	 */
	public NLGRealiser getRealiser() {
		return realiser;
	}

	/**
	 * @param realiser
	 *            the realiser to set
	 */
	public void setRealiser(NLGRealiser realiser) {
		this.realiser = realiser;
	}

	/**
	 * This is the principal method to generate a text, and models the
	 * generation pipeline. Starting from an ontology, it (a) plans the document
	 * and selects content; (b) passes the result to the microplanner; (c)
	 * ralises the result as a string.
	 * 
	 * @param ontology
	 *            the ontology containing the instances or messages
	 * @return a string representing the document.
	 */
	public String generate(OntologyHandler ontology) {
		DocPlan doc = this.docplanner.planDocument(ontology);
		this.microplanner.microplanDoc(doc);
		String realisation = this.realiser.realiseDoc(doc);
		return realisation;
	}

}
