package mt.edu.um.nlgapp.microplan;

import mt.edu.um.nlgapp.docplan.DocPlan;
import simplenlg.framework.NLGFactory;
import simplenlg.realiser.english.Realiser;

/**
 * This interface defines the API for a realiser. A realiser should take a
 * {@link mt.edu.um.nlgapp.docplan.DocPlan}, after the
 * {@link mt.edu.um.nlgapp.microplan.Microplanner#microplanDoc}
 * has been called, and map each of its messages to a <code>String</code>.
 * 
 * @author bertugatt
 * 
 */
public abstract class NLGRealiser {

	private NLGFactory factory;
	private Realiser realiser;

	/**
	 * Constructor: The NLGRealiser needs a
	 * {@link simplenlg.framework.NLGFactory} to construct phrases and a
	 * {@link simplenlg.realiser.english.Realiser} to turn the phrases into
	 * <code>String</code>s.
	 * 
	 * @param factory
	 *            The NLGFactory
	 * @param realiser
	 *            the realiser
	 */
	public NLGRealiser(NLGFactory factory, Realiser realiser) {
		this.factory = factory;
		this.realiser = realiser;
	}

	/**
	 * This is the principal method in the <code>NLGRealiser</code>. It takes a
	 * plan, whose nodes have been micro-planned, and returns the
	 * <code>String</code> representing the document.
	 * 
	 * @param doc
	 *            the doc plan, whose nodes have lexical templates
	 * @return the text itself
	 */
	public abstract String realiseDoc(DocPlan doc);

}
