/*
 * File: OntologyInstanceFilter
 *
 * CHANGE HISTORY
 * 0.4	02/02/09	Base line file
 */

/*
 * Copyright (c) 2009, the University of Aberdeen
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted FOR RESEARCH PURPOSES ONLY, provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, 
 * 		this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation and/or 
 *    other materials provided with the distribution.
 * 3. Neither the name of the University of Aberdeen nor the names of its contributors 
 * 	  may be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 *    THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *    ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE 
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 *    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND 
 *     ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 *     EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *     
 *  Redistribution and use for purposes other than research requires special permission by the
 *  copyright holders and contributors. Please contact Ehud Reiter (e.reiter@abdn.ac.uk) for
 *  more information.
 */
package uk.ac.abdn.carados;

/**
 * <p>This interface allows filtering to be done on the instances returned by the 
 * getAllInstances methods on the class and in the ontology. Essentially this 
 * restricts the collection to be a subset of the full set of instances. Only those
 * instances that meet the requirements of the filter are included. The application 
 * using this package will need to define it's own Filter to be used.</p>
 * 
 * @author D. Westwater, University of Aberdeen
 * @since 0.4
 */
public interface OntologyInstanceFilter {

	/**
	 * The method that is called when a collection of instances is being retrieved.
	 * The implemented filter then has the option to reject this instance from the 
	 * collection.
	 * @param instance the instance being checked.
	 * @return <code>true</code> if the instance can be included, <code>false</code>
	 * otherwise.
	 */
	public boolean canInclude(OntologyInstanceHandler instance);
}
