/*
 * File: SimpleCaradosXMLFormat
 *
 * CHANGE HISTORY
 * 0.1	14/01/09	Base line file
 * 0.5	09/02/09	Externalised strings.
 */

/*
 * Copyright (c) 2007-2007, the University of Aberdeen
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted FOR RESEARCH PURPOSES ONLY, provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, 
 * 		this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation and/or 
 *    other materials provided with the distribution.
 * 3. Neither the name of the University of Aberdeen nor the names of its contributors 
 * 	  may be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 *    THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *    ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE 
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 *    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND 
 *     ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 *     EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *     
 *  Redistribution and use for purposes other than research requires special permission by the
 *  copyright holders and contributors. Please contact Ehud Reiter (e.reiter@abdn.ac.uk) for
 *  more information.
 */
package uk.ac.abdn.carados.simple;

/**
 * <p>This class contains the formatting information for the SimpleOntologyXML.
 * The layout for which, is:<br>
 * <code>
 * <blockquote>
 * &lt;ontology name="..."&gt;<br>
 * &nbsp;&nbsp;&nbsp;&lt;class name="..."&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;property name="..." type="..." value="..." /&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;property name="..." type="..." value="..." /&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;...<br>
 * &nbsp;&nbsp;&nbsp;&lt;/class&gt;<br>
 * &nbsp;&nbsp;&nbsp;&lt;class name="..."&gt;<br>
 * &nbsp;&nbsp;&nbsp;...<br>
 * &nbsp;&nbsp;&nbsp;&lt;/class&gt;<br>
 * &nbsp;&nbsp;&nbsp;...<br>
 * &nbsp;&nbsp;&nbsp;&lt;instance name="..." class="..."&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;property name="..." type="..." value="..." /&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;property name="..." type="..." value="..." /&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;...<br>
 * &nbsp;&nbsp;&nbsp;&lt;/instance&gt;<br>
 * &nbsp;&nbsp;&nbsp;&lt;instance name="..." class="..."&gt;<br>
 * &nbsp;&nbsp;&nbsp;...<br>
 * &nbsp;&nbsp;&nbsp;&lt;/instance&gt;<br>
 * &nbsp;&nbsp;&nbsp;...<br>
 * &nbsp;&nbsp;&nbsp;&lt;hierarchy&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;parent name="..."&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;child name="..."/&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;child name="..."/&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;...<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;/parent&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;parent name="..."&gt;<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;...<br>
 * &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&lt;/parent&gt;<br>
 * &nbsp;&nbsp;&nbsp;&lt;/hierarchy&gt;<br>
 * &lt;/ontology&gt;<br>
 * </blockquote>
 * </code>
 * The properties recorded under the <em>class</em> tag represent the default values for
 * those properties for the given class. The hierarchy of classes is recorded separately
 * from the class definitions to avoid any looping with the class structure.
 * </p>
 * <h4>Release Notes</h4>
 * <p>Version 0.5 - Externalised strings.</p>
 * @author D.Westwater & A.Gatt, University of Aberdeen
 */
public abstract class SimpleCaradosXMLFormat {
	/** The top level node for the XML format. */
	public final static String ROOT_NODE = "ontology"; //$NON-NLS-1$

	/** The tag for representing ontology classes. */
	public final static String CLASS_NODE = "class"; //$NON-NLS-1$

	/** The node path for classes. */
	public final static String CLASS_NODE_PATH = "/ontology/class"; //$NON-NLS-1$
	
	/** The tag for representing ontology instances. */
	public final static String INSTANCE_NODE = "instance"; //$NON-NLS-1$

	/** The node path for instances. */
	public final static String INSTANCE_NODE_PATH = "/ontology/instance"; //$NON-NLS-1$

	/** The tag for representing properties. */
	public final static String PROPERTY_NODE = "property"; //$NON-NLS-1$

	/** The tag for representing the class hierarchy. */
	public final static String HIERARCHY_NODE = "hierarchy"; //$NON-NLS-1$

	/** The tag for representing the parent in the class hierarchy. */
	public final static String PARENT_NODE = "parent"; //$NON-NLS-1$

	/** The node path for parent classes in the class hiearchy. */
	public final static String PARENT_NODE_PATH = "/ontology/hierarchy/parent"; //$NON-NLS-1$
	
	/** The tag for representing the child in the class hierarchy. */
	public final static String CHILD_NODE = "child"; //$NON-NLS-1$
	
	/** The title of the <em>name</em> attribute. */
	public final static String NAME_ATTRIBUTE = "name";  //$NON-NLS-1$
	
	/** The title of the <em>type</em> attribute. */
	public final static String TYPE_ATTRIBUTE = "type";  //$NON-NLS-1$
	
	/** The title of the <em>value</em> attribute. */
	public final static String VALUE_ATTRIBUTE = "value";  //$NON-NLS-1$
	
	/** The title of the <em>value</em> attribute. */
	public final static String CLASS_ATTRIBUTE = "class";  //$NON-NLS-1$

}
