/*
 * File: SimpleMessages
 *
 * CHANGE HISTORY
 * 0.5	12/02/09	Base line file
 * 0.9	28/05/09	getString(...) no longer traps MissingResourceException
 * 
 * NB - Version numbers refer to the package version not the file version!
 */

/*
 * Copyright (c) 2009, the University of Aberdeen
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted FOR RESEARCH PURPOSES ONLY, provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, 
 * 		this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation and/or 
 *    other materials provided with the distribution.
 * 3. Neither the name of the University of Aberdeen nor the names of its contributors 
 * 	  may be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 *    THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *    ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE 
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 *    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND 
 *     ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 *     EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *     
 *  Redistribution and use for purposes other than research requires special permission by the
 *  copyright holders and contributors. Please contact Ehud Reiter (e.reiter@abdn.ac.uk) for
 *  more information.
 */
package uk.ac.abdn.carados.simple;

import java.util.ResourceBundle;

/**
 * <p>
 * This class is purely for handling external resources, i.e. the string messages. 
 * Externalised strings are stored in ban.properties and can be changed without
 * the need for changing this code.
 * </p>
 * <h4>Release Notes</h4>
 * <p>Version 0.9 - getString(String) throws MissingResourceException.</p>
 * @author D. Westwater, University of Aberdeen
 * @since 0.5
 */
public class SimpleMessages {
	
	/** The full path name of the bundled resource. */
	private static final String BUNDLE_NAME = "uk.ac.abdn.carados.simple.simple"; //$NON-NLS-1$

	/** The local reference to the resource bundle. */
	private static final ResourceBundle RESOURCE_BUNDLE = ResourceBundle
			.getBundle(BUNDLE_NAME);

	/**
	 * Retrieves the externalised string with the given key.
	 * @param key the key for the externalised string.
	 * @return the real value of the externalised string or if the key is 
	 * not found then the key itself is returned.
	 */
	public static String getString(String key) {
		return RESOURCE_BUNDLE.getString(key);
	}
}
