package uk.ac.abdn.carados.simple.test;

import java.net.URI;
import java.util.Collection;

import uk.ac.abdn.carados.OntologyClassHandler;
import uk.ac.abdn.carados.OntologyHandler;
import uk.ac.abdn.carados.OntologyInstanceHandler;
import uk.ac.abdn.carados.OntologyListener;


public class MySimpleCaradosTest implements Runnable, OntologyListener {
	
	/**
	 * @param args
	 */
	public static void main(String[] args) {
		MySimpleCaradosTest test = new MySimpleCaradosTest();
		Thread t = new Thread(test);
		t.start();
	}

	@SuppressWarnings("nls")
	@Override
	public void run() {
		try {
			OntologyHandler ontologyHandler = (OntologyHandler) (Class.forName(
					"uk.ac.abdn.carados.simple.SimpleCaradosOntology")
					.newInstance());
			
			ontologyHandler.attachListener(this);

			ontologyHandler.loadOntology(new 
					URI("file:///E:/dw/workspace/babytalk/testOnto.xml"));
			
			Collection<OntologyClassHandler> allClasses = 
				ontologyHandler.getAllOntologyClasses();
			
			System.out.println("\n\nClasses in the ontology: ");
			for (OntologyClassHandler eachClass : allClasses)
			{
				System.out.println("   " + eachClass.getName());
			}
			
			System.out.println("\nDirect sub-classes of root class:");
			allClasses = ontologyHandler.getRootClass().getSubClasses(false);
			for (OntologyClassHandler eachClass : allClasses)
			{
				System.out.println("   " + eachClass.getName());
			}
			
			System.out.println("\nAll sub-classes of ANIMAL class:");
			allClasses = ontologyHandler.getOntologyClass("ANIMAL")
			.getSubClasses(true);
			for (OntologyClassHandler eachClass : allClasses)
			{
				System.out.println("   " + eachClass.getName());
			}
			
			System.out.println("\nAll direct super-classes of DOG class:");
			allClasses = ontologyHandler.getOntologyClass("DOG")
			.getSuperClasses(false);
			for (OntologyClassHandler eachClass : allClasses)
			{
				System.out.println("   " + eachClass.getName());
			}
			
			System.out.println("\nAll super-classes of DOG class:");
			allClasses = ontologyHandler.getOntologyClass("DOG")
			.getSuperClasses(true);
			for (OntologyClassHandler eachClass : allClasses)
			{
				System.out.println("   " + eachClass.getName());
			}
			
			System.out.println("\nAll Direct super-classes of DOG after modifying hierarchy:");
			OntologyClassHandler dogClass = ontologyHandler.getOntologyClass("DOG");
			OntologyClassHandler animalClass = ontologyHandler.getOntologyClass("ANIMAL");
			dogClass.setDirectSuperClass(animalClass);
			allClasses = dogClass.getSuperClasses(false);
			for (OntologyClassHandler eachClass : allClasses)
			{
				System.out.println("   " + eachClass.getName());
			}
			
			System.out.println("Contains DOG class: " + 
					ontologyHandler.containsClass("DOG"));
			
			System.out.println("Contains CAT class: " + 
					ontologyHandler.containsClass("CAT"));
			
			OntologyClassHandler girlClass = ontologyHandler.getOntologyClass("GIRL");
			Collection<OntologyInstanceHandler> girlInstances = 
				girlClass.getInstances(false);
			
			OntologyInstanceHandler girl1 = (OntologyInstanceHandler) 
			girlInstances.toArray()[1];
			
			System.out.println("Contains " + girl1.getName() + " instance: " + 
					ontologyHandler.containsInstance(girl1));
			girl1.delete();
			System.out.println("Contains " + girl1.getName() + 
					" instance after deletion: " + 
					ontologyHandler.containsInstance(girl1));
			
			
			System.out.println("The properties in the ontology: ");
			Collection<String> properties = ontologyHandler.getPropertyNames();
			for (String eachProperty : properties)
			{
				System.out.println("   " + eachProperty);
			}
			
			System.out.println("Contains property 'eats': " + 
					ontologyHandler.containsProperty("eats"));
			
			System.out.println("Contains property 'numLegs': " + 
					ontologyHandler.containsProperty("numLegs"));
			
			animalClass.setDefaultValue("numLegs", new Integer(4));
			System.out.println("Contains property 'numLegs' after addition: " + 
					ontologyHandler.containsProperty("numLegs"));
			
			System.out.println("Default value for DOG.numLegs: " + 
					dogClass.getDefaultValue("numLegs", true));
			
			System.out.println("The properties in the ontology: ");
			properties = ontologyHandler.getPropertyNames();
			for (String eachProperty : properties)
			{
				System.out.println("   " + eachProperty);
			}
			
			OntologyInstanceHandler girlInstance = girlClass.createInstance();
			girlInstance.addOwnValue("numLegs", new Integer(2));
			
			System.out.println(girlInstance.getName() + " has numLegs: " + 
					girlInstance.getOwnValue("numLegs"));
			
			ontologyHandler.saveOntology("E:/dw/workspace/babytalk/testOntoMod.xml");
		} catch (Exception e) {
			e.printStackTrace();
		}
		/*
		OntologyHandler owl2 = new Owl2CaradosOntology();
		try {
			owl2.loadOntology(URI.
					create("file:///E:/dw/workspace/babytalk/res/babytalk.owl"));
		} catch (OntologyException e) {
		}
		try {
			Document doc = SimpleCaradosXMLEncoder.encodeOntology(owl2);
			if (doc != null) {
				try {
					DOMUtil.saveDocument(doc, "E:/dw/workspace/babytalk/res/babytalk.owl.xml");
				} catch (DOMUtilException e) {
					throw new OntologyException("Could not save ontology: "
							+ e.getMessage());
				}
			}
		} catch (OntologyException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}
		*/
	}

	@SuppressWarnings("nls")
	@Override
	public void classCreated(OntologyClassHandler ontologyClass)
	{
		System.out.println("Log: Creating class: " + ontologyClass.getName());
	}

	@SuppressWarnings("nls")
	@Override
	public void defaultValueChanged(OntologyClassHandler ontologyClass,
			String propertyName, Object propertyValue) {
		System.out.println("Log: Default value for " + ontologyClass.getName() + 
				" has changed: " + propertyName + " - " + propertyValue.toString());
	}

	@SuppressWarnings("nls")
	@Override
	public void instanceCreated(OntologyInstanceHandler instance) {
		System.out.println("Log: created instance: " + instance.getName());
	}

	@SuppressWarnings("nls")
	@Override
	public void propertyValueChanged(OntologyInstanceHandler instance,
			String propertyName, Object propertyValue, boolean overwritten) {
		
		if (overwritten)
		{
			System.out.println("Log: property value for " + instance.getName() + 
				" has changed: " + propertyName + " - " + propertyValue.toString());
		}
		else
		{
			System.out.println("Log: property value for " + instance.getName() + 
					" has been added to: " + propertyName + " - " + 
					propertyValue.toString());
		}
	}

	@SuppressWarnings("nls")
	@Override
	public void saved(String fileName, String ontologyName) {
		System.out.println("Log: saving ontology: " + ontologyName + " > " + 
				fileName);
	}

	@SuppressWarnings("nls")
	@Override
	public void subClassAdded(OntologyClassHandler baseClass,
			OntologyClassHandler subClass) {
		System.out.println("Log: new subclass for " + baseClass.getName() + 
				": " + subClass.getName());
	}

	@SuppressWarnings("nls")
	@Override
	public void superClassAdded(OntologyClassHandler baseClass,
			OntologyClassHandler superClass, boolean overwritten) {
		
		if (overwritten)
		{
			System.out.println("Log: Direct super class for " + baseClass.getName() + 
					" is now " + superClass.getName());
		}
		else
		{
			System.out.println("Log: new super class for " + baseClass.getName() + 
					" has been added: " + superClass.getName());
		}
	}

	@SuppressWarnings("nls")
	@Override
	public void classDeleted(String className) {
		System.out.println("Log: class has been deleted: " + className);
	}

	@SuppressWarnings("nls")
	@Override
	public void instanceDeleted(String instanceName) {
		System.out.println("Log: instance has been deleted: " + instanceName);
	}

	@SuppressWarnings("nls")
	@Override
	public void subClassRemoved(OntologyClassHandler baseClass,
			OntologyClassHandler subClass) {
		System.out.println("Log: " + subClass.getName() + 
				" is no longer a subclass of " + baseClass.getName());
	}

	@SuppressWarnings("nls")
	@Override
	public void superClassRemoved(OntologyClassHandler baseClass,
			OntologyClassHandler superClass) {
		System.out.println("Log: " + superClass.getName() + 
				" is no longer a superclass of " + baseClass.getName());
	}

	@SuppressWarnings("nls")
	@Override
	public void missingProperty(String property) {
		System.out.println("Log: " + property + " does not exist.");
	}

	@Override
	public void typeConflict(String property, Object value) {
		System.out.println("Log: " + property +  //$NON-NLS-1$
				" does not take: " + value.toString()); //$NON-NLS-1$
	}
}
