/*
 * File: DateAfterFilter
 *
 * CHANGE HISTORY
 * 0.6	20/02/09	Base line file
 */

/*
 * Copyright (c) 2009 the University of Aberdeen
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted FOR RESEARCH PURPOSES ONLY, provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, 
 * 		this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation and/or 
 *    other materials provided with the distribution.
 * 3. Neither the name of the University of Aberdeen nor the names of its contributors 
 * 	  may be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 *    THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *    ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE 
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 *    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND 
 *     ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 *     EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *     
 *  Redistribution and use for purposes other than research requires special permission by the
 *  copyright holders and contributors. Please contact Ehud Reiter (e.reiter@abdn.ac.uk) for
 *  more information.
 */
package uk.ac.abdn.carados.util;

import uk.ac.abdn.carados.OntologyInstanceFilter;
import uk.ac.abdn.carados.OntologyInstanceHandler;
import java.util.Date;

/**
 * <p>A convenience class that implements the OntologyInstanceFilter to 
 * filter instances on a date property. Instances whose date is equal to
 * or after a reference date are included in the filtered collection.</p>
 * @author D. Westwater, University of Aberdeen
 */
public class DateAfterFilter implements OntologyInstanceFilter {

	/** The property to do the comparison on. */
	private String _property;
	
	/** The reference date. */
	private Date _when;
	
	/**
	 * Creates a new filter using the provided property name and date.
	 * @param propertyName the name of the property to compare on.
	 * @param when the reference date.
	 */
	public DateAfterFilter(String propertyName, Date when) {
		this._property = propertyName;
		this._when = when;
	}
	
	@Override
	public boolean canInclude(OntologyInstanceHandler instance) {
		boolean include = false;
		Date date = instance.getOwnValueAsDate(this._property);
		
		if (this._when != null && date != null && 
				this._when.compareTo(date) <= 0) {
			
			include = true;
		}
		
		return include; 
	}

}
