/*
 * File: IntegerFilter
 *
 * CHANGE HISTORY
 * 0.7	26/02/09	Base line file
 */

/*
 * Copyright (c) 2009 the University of Aberdeen
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification, 
 * are permitted FOR RESEARCH PURPOSES ONLY, provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice, 
 * 		this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright notice, 
 *    this list of conditions and the following disclaimer in the documentation and/or 
 *    other materials provided with the distribution.
 * 3. Neither the name of the University of Aberdeen nor the names of its contributors 
 * 	  may be used to endorse or promote products derived from this software without 
 *    specific prior written permission.
 *    
 *    THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 *    AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
 *    THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 *    ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE 
 *    FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
 *    (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 *     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND 
 *     ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT 
 *     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, 
 *     EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *     
 *  Redistribution and use for purposes other than research requires special permission by the
 *  copyright holders and contributors. Please contact Ehud Reiter (e.reiter@abdn.ac.uk) for
 *  more information.
 */
package uk.ac.abdn.carados.util;

import uk.ac.abdn.carados.OntologyInstanceFilter;
import uk.ac.abdn.carados.OntologyInstanceHandler;

/**
 * <p>A convenience class that implements the OntologyInstanceFilter to 
 * filter instances on an integer property. The comparison is done against
 * a set value.</p>
 * @author D. Westwater, University of Aberdeen
 * @since 0.7
 */
public class IntegerFilter implements OntologyInstanceFilter {

	/** The property to do the comparison on. */
	private String _property;
	
	/** The reference value. */
	private int _value;
	
	/** The mode of operation. */
	private ValueComparison _mode;
	
	/**
	 * Creates a new filter using the provided property name and integer value.
	 * @param propertyName the name of the property to compare on.
	 * @param value the reference value.
	 * @param mode the comparison mode.
	 */
	public IntegerFilter(String propertyName, int value, ValueComparison mode) {
		this._property = propertyName;
		this._value = value;
		this._mode = mode;
	}
	
	/**
	 * Resets the reference value
	 * @param value the reference value.
	 */
	public void setValue(int value) {
		this._value = value;
	}
	
	/**
	 * Resets the mode for this filter.
	 * @param mode the comparison mode.
	 */
	public void setMode(ValueComparison mode) {
		this._mode = mode;
	}
	
	@Override
	public boolean canInclude(OntologyInstanceHandler instance) {
		boolean include = false;
		int propertyValue = instance.getOwnValueAsInteger(this._property).intValue();
		
		switch (this._mode)
		{
		case EQUAL:
			include = (propertyValue == this._value);
			break;
			
		case LESS_EQUAL:
			include = (propertyValue <= this._value);
			break;
			
		case GREATER_EQUAL:
			include = (propertyValue >= this._value);
			break;
			
		case LESS_THAN:
			include = (propertyValue < this._value);
			break;
			
		case GREATER_THAN:
			include = (propertyValue > this._value);
			break;
			
		case NOT_EQUAL:
			include = (propertyValue != this._value);
			break;
		}
		
		return include; 
	}
}
